##  How to Support ERP Transformation with SAP LeanIX?
SAP LeanIX supports organizations in all phases of their multi-year ERP transformation journeys. The following pages outline a step-by-step approach based on proven best practices for organizations to extract maximum benefit from SAP LeanIX in their ERPs. This follows the 6 phases of the SAP Activate framework, which you can apply to any other ERP transformation scenario. The strong suit of SAP LeanIX applies in particular to the first phases of an organization’s ERP transformation: Discover, Prepare, Explore, and Realize (partially). After that, you can continue to track any ongoing changes during the transformation using SAP LeanIX and will support further activities that are necessary to finalize the transformation (for example, sunsetting older systems).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioa8cb5c8ea91544b0b6cdb252e4797358_LowRes.png)
YesNo
Send
